Index: main/waeup.kofa/trunk/src/waeup/kofa/students/__init__.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/__init__.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/__init__.py	(revision 7811)
@@ -2,12 +2,12 @@
 """
 # Make this a package.
-from waeup.sirp.students.student import (
+from waeup.kofa.students.student import (
     Student, StudentFactory
     )
-from waeup.sirp.students.container import StudentsContainer
-from waeup.sirp.students.studycourse import StudentStudyCourse
-from waeup.sirp.students.payments import StudentPaymentsContainer
-from waeup.sirp.students.accommodation import StudentAccommodation
-from waeup.sirp.students.dynamicroles import StudentPrincipalRoleManager
+from waeup.kofa.students.container import StudentsContainer
+from waeup.kofa.students.studycourse import StudentStudyCourse
+from waeup.kofa.students.payments import StudentPaymentsContainer
+from waeup.kofa.students.accommodation import StudentAccommodation
+from waeup.kofa.students.dynamicroles import StudentPrincipalRoleManager
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/accommodation.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/accommodation.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/accommodation.py	(revision 7811)
@@ -23,8 +23,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.sirp.interfaces import academic_sessions_vocab
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.interfaces import academic_sessions_vocab
+from waeup.kofa.students.interfaces import (
     IStudentAccommodation, IStudentNavigation, IBedTicket)
-from waeup.sirp.utils.helpers import attrs_to_fields
+from waeup.kofa.utils.helpers import attrs_to_fields
 
 class StudentAccommodation(grok.Container):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/authentication.py	(revision 7811)
@@ -28,9 +28,9 @@
 from zope.publisher.interfaces.http import IHTTPRequest
 from zope.session.interfaces import ISession
-from waeup.sirp.authentication import (
-    SIRPPrincipalInfo, get_principal_role_manager)
-from waeup.sirp.interfaces import (
+from waeup.kofa.authentication import (
+    KOFAPrincipalInfo, get_principal_role_manager)
+from waeup.kofa.interfaces import (
     IAuthPluginUtility, IUserAccount, IPasswordValidator)
-from waeup.sirp.students.interfaces import IStudent
+from waeup.kofa.students.interfaces import IStudent
 
 class StudentAccount(grok.Adapter):
@@ -135,5 +135,5 @@
         if not account.checkPassword(credentials['password']):
             return None
-        return SIRPPrincipalInfo(id=account.name,
+        return KOFAPrincipalInfo(id=account.name,
                              title=account.title,
                              description=account.description,
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/batching.py	(revision 7811)
@@ -32,14 +32,14 @@
 from zope.catalog.interfaces import ICatalog
 from hurry.workflow.interfaces import IWorkflowState
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IBatchProcessor, FatalCSVError, IObjectConverter, IUserAccount,
     IObjectHistory)
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudent, IStudentStudyCourse,
     IStudentUpdateByRegNo, IStudentUpdateByMatricNo,
     IStudentStudyLevel, ICourseTicket,
     IStudentOnlinePayment)
-from waeup.sirp.students.workflow import  IMPORTABLE_STATES
-from waeup.sirp.utils.batching import BatchProcessor
+from waeup.kofa.students.workflow import  IMPORTABLE_STATES
+from waeup.kofa.utils.batching import BatchProcessor
 
 class StudentProcessor(BatchProcessor):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser.py	(revision 7811)
@@ -29,22 +29,22 @@
 from zope.formlib.textwidgets import BytesDisplayWidget
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
-from waeup.sirp.accesscodes import (
+from waeup.kofa.accesscodes import (
     invalidate_accesscode, get_access_code, create_accesscode)
-from waeup.sirp.accesscodes.workflow import USED
-from waeup.sirp.browser import (
-    SIRPPage, SIRPEditFormPage, SIRPAddFormPage, SIRPDisplayFormPage,
-    ContactAdminForm, SIRPForm)
-from waeup.sirp.browser.interfaces import ICaptchaManager
-from waeup.sirp.browser.breadcrumbs import Breadcrumb
-from waeup.sirp.browser.resources import datepicker, datatable, tabs, warning
-from waeup.sirp.browser.layout import jsaction, action, UtilityView
-from waeup.sirp.interfaces import (
-    ISIRPObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm,
-    ISIRPUtils, IUniversity)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.widgets.datewidget import (
+from waeup.kofa.accesscodes.workflow import USED
+from waeup.kofa.browser import (
+    KOFAPage, KOFAEditFormPage, KOFAAddFormPage, KOFADisplayFormPage,
+    ContactAdminForm, KOFAForm)
+from waeup.kofa.browser.interfaces import ICaptchaManager
+from waeup.kofa.browser.breadcrumbs import Breadcrumb
+from waeup.kofa.browser.resources import datepicker, datatable, tabs, warning
+from waeup.kofa.browser.layout import jsaction, action, UtilityView
+from waeup.kofa.interfaces import (
+    IKOFAObject, IUserAccount, IExtFileStore, IPasswordValidator, IContactForm,
+    IKOFAUtils, IUniversity)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.widgets.datewidget import (
     FriendlyDateWidget, FriendlyDateDisplayWidget,
     FriendlyDatetimeDisplayWidget)
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentsContainer, IStudent, IStudentClearance,
     IStudentPersonal, IStudentBase, IStudentStudyCourse,
@@ -53,15 +53,15 @@
     IStudentOnlinePayment, IBedTicket, IStudentsUtils, IStudentChangePassword
     )
-from waeup.sirp.students.catalog import search
-from waeup.sirp.students.workflow import (ADMITTED, PAID,
+from waeup.kofa.students.catalog import search
+from waeup.kofa.students.workflow import (ADMITTED, PAID,
     CLEARANCE, REQUESTED, RETURNING, CLEARED, REGISTERED, VALIDATED)
-from waeup.sirp.students.studylevel import StudentStudyLevel, CourseTicket
-from waeup.sirp.students.vocabularies import StudyLevelSource
-from waeup.sirp.browser.resources import toggleall
-from waeup.sirp.hostels.hostel import NOT_OCCUPIED
-from waeup.sirp.utils.helpers import get_current_principal
+from waeup.kofa.students.studylevel import StudentStudyLevel, CourseTicket
+from waeup.kofa.students.vocabularies import StudyLevelSource
+from waeup.kofa.browser.resources import toggleall
+from waeup.kofa.hostels.hostel import NOT_OCCUPIED
+from waeup.kofa.utils.helpers import get_current_principal
 
 def write_log_message(view, message):
-    ob_class = view.__implemented__.__name__.replace('waeup.sirp.','')
+    ob_class = view.__implemented__.__name__.replace('waeup.kofa.','')
     view.context.getStudent().loggerInfo(ob_class, message)
     return
@@ -155,11 +155,11 @@
     @property
     def title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         # There is no request attribute, thus we can only translate
         # to the default (portal) language
-        return translate(self.context.level_title, 'waeup.sirp',
+        return translate(self.context.level_title, 'waeup.kofa',
             target_language=portal_language)
 
-class StudentsContainerPage(SIRPPage):
+class StudentsContainerPage(KOFAPage):
     """The standard view for student containers.
     """
@@ -194,5 +194,5 @@
         return
 
-class StudentsContainerManagePage(SIRPPage):
+class StudentsContainerManagePage(KOFAPage):
     """The manage page for student containers.
     """
@@ -245,5 +245,5 @@
         return
 
-class StudentAddFormPage(SIRPAddFormPage):
+class StudentAddFormPage(KOFAAddFormPage):
     """Add-form to add a student.
     """
@@ -265,5 +265,5 @@
         return
 
-class StudentBaseDisplayFormPage(SIRPDisplayFormPage):
+class StudentBaseDisplayFormPage(KOFADisplayFormPage):
     """ Page to display student base data
     """
@@ -310,6 +310,6 @@
         usertype = getattr(self.request.principal,
                            'user_type', 'system').title()
-        sirp_utils = getUtility(ISIRPUtils)
-        success = sirp_utils.sendContactForm(
+        kofa_utils = getUtility(IKOFAUtils)
+        success = kofa_utils.sendContactForm(
                 self.request.principal.title,email,
                 self.context.display_fullname,self.context.email,
@@ -323,5 +323,5 @@
         return
 
-class StudentBaseManageFormPage(SIRPEditFormPage):
+class StudentBaseManageFormPage(KOFAEditFormPage):
     """ View to manage student base data
     """
@@ -388,5 +388,5 @@
         return
 
-class StudentClearanceDisplayFormPage(SIRPDisplayFormPage):
+class StudentClearanceDisplayFormPage(KOFADisplayFormPage):
     """ Page to display student clearance data
     """
@@ -415,13 +415,13 @@
     @property
     def title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        return translate(_('Clearance Data'), 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        return translate(_('Clearance Data'), 'waeup.kofa',
             target_language=portal_language)
 
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         return translate(_('Clearance Slip of '),
-            'waeup.sirp', target_language=portal_language) \
+            'waeup.kofa', target_language=portal_language) \
             + ' %s' % self.context.display_fullname
 
@@ -434,5 +434,5 @@
             self.context.getStudent(), studentview)
 
-class StudentClearanceManageFormPage(SIRPEditFormPage):
+class StudentClearanceManageFormPage(KOFAEditFormPage):
     """ Page to edit student clearance data
     """
@@ -508,5 +508,5 @@
         return
 
-class StudentPersonalDisplayFormPage(SIRPDisplayFormPage):
+class StudentPersonalDisplayFormPage(KOFADisplayFormPage):
     """ Page to display student personal data
     """
@@ -523,5 +523,5 @@
             mapping = {'a':self.context.display_fullname})
 
-class StudentPersonalManageFormPage(SIRPEditFormPage):
+class StudentPersonalManageFormPage(KOFAEditFormPage):
     """ Page to edit student clearance data
     """
@@ -538,5 +538,5 @@
         return
 
-class StudyCourseDisplayFormPage(SIRPDisplayFormPage):
+class StudyCourseDisplayFormPage(KOFADisplayFormPage):
     """ Page to display the student study course data
     """
@@ -556,5 +556,5 @@
     def current_mode(self):
         if self.context.certificate is not None:
-            studymodes_dict = getUtility(ISIRPUtils).getStudyModesDict()
+            studymodes_dict = getUtility(IKOFAUtils).getStudyModesDict()
             return studymodes_dict[self.context.certificate.study_mode]
         return
@@ -572,5 +572,5 @@
         return
 
-class StudyCourseManageFormPage(SIRPEditFormPage):
+class StudyCourseManageFormPage(KOFAEditFormPage):
     """ Page to edit the student study course data
     """
@@ -645,5 +645,5 @@
         return
 
-class StudyLevelDisplayFormPage(SIRPDisplayFormPage):
+class StudyLevelDisplayFormPage(KOFADisplayFormPage):
     """ Page to display student study levels
     """
@@ -662,7 +662,7 @@
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
-        level_title = translate(self.context.level_title, 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
+        level_title = translate(self.context.level_title, 'waeup.kofa',
             target_language=lang)
         return _('${a}: Study Level ${b}', mapping = {
@@ -688,34 +688,34 @@
     @property
     def title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        return translate(_('Level Data'), 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        return translate(_('Level Data'), 'waeup.kofa',
             target_language=portal_language)
 
     @property
     def content_title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        return translate(_('Course List'), 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        return translate(_('Course List'), 'waeup.kofa',
             target_language=portal_language)
 
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
-        level_title = translate(self.context.level_title, 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
+        level_title = translate(self.context.level_title, 'waeup.kofa',
             target_language=lang)
         return translate(_('Course Registration Slip  '),
-            'waeup.sirp', target_language=portal_language) \
+            'waeup.kofa', target_language=portal_language) \
             + ' %s' % level_title
 
     def render(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        Sem = translate(_('Sem.'), 'waeup.sirp', target_language=portal_language)
-        Code = translate(_('Code'), 'waeup.sirp', target_language=portal_language)
-        Title = translate(_('Title'), 'waeup.sirp', target_language=portal_language)
-        Dept = translate(_('Dept.'), 'waeup.sirp', target_language=portal_language)
-        Faculty = translate(_('Faculty'), 'waeup.sirp', target_language=portal_language)
-        Cred = translate(_('Cred.'), 'waeup.sirp', target_language=portal_language)
-        Mand = translate(_('Mand.'), 'waeup.sirp', target_language=portal_language)
-        Score = translate(_('Score'), 'waeup.sirp', target_language=portal_language)
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        Sem = translate(_('Sem.'), 'waeup.kofa', target_language=portal_language)
+        Code = translate(_('Code'), 'waeup.kofa', target_language=portal_language)
+        Title = translate(_('Title'), 'waeup.kofa', target_language=portal_language)
+        Dept = translate(_('Dept.'), 'waeup.kofa', target_language=portal_language)
+        Faculty = translate(_('Faculty'), 'waeup.kofa', target_language=portal_language)
+        Cred = translate(_('Cred.'), 'waeup.kofa', target_language=portal_language)
+        Mand = translate(_('Mand.'), 'waeup.kofa', target_language=portal_language)
+        Score = translate(_('Score'), 'waeup.kofa', target_language=portal_language)
         studentview = StudentBaseDisplayFormPage(self.context.getStudent(),
             self.request)
@@ -735,5 +735,5 @@
             tabledata=tabledata)
 
-class StudyLevelManageFormPage(SIRPEditFormPage):
+class StudyLevelManageFormPage(KOFAEditFormPage):
     """ Page to edit the student study level data
     """
@@ -762,7 +762,7 @@
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
-        level_title = translate(self.context.level_title, 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
+        level_title = translate(self.context.level_title, 'waeup.kofa',
             target_language=lang)
         return _('Manage study level ${a}',
@@ -853,5 +853,5 @@
         return
 
-class CourseTicketAddFormPage(SIRPAddFormPage):
+class CourseTicketAddFormPage(KOFAAddFormPage):
     """Add a course ticket.
     """
@@ -890,5 +890,5 @@
         self.redirect(self.url(self.context))
 
-class CourseTicketDisplayFormPage(SIRPDisplayFormPage):
+class CourseTicketDisplayFormPage(KOFADisplayFormPage):
     """ Page to display course tickets
     """
@@ -906,5 +906,5 @@
             'b':self.context.code})
 
-class CourseTicketManageFormPage(SIRPEditFormPage):
+class CourseTicketManageFormPage(KOFAEditFormPage):
     """ Page to manage course tickets
     """
@@ -925,5 +925,5 @@
         return
 
-class PaymentsManageFormPage(SIRPEditFormPage):
+class PaymentsManageFormPage(KOFAEditFormPage):
     """ Page to manage the student payments
 
@@ -982,5 +982,5 @@
         self.redirect(self.url(self.context, '@@addop'))
 
-class OnlinePaymentAddFormPage(SIRPAddFormPage):
+class OnlinePaymentAddFormPage(KOFAAddFormPage):
     """ Page to add an online payment ticket
     """
@@ -1039,5 +1039,5 @@
         return
 
-class OnlinePaymentDisplayFormPage(SIRPDisplayFormPage):
+class OnlinePaymentDisplayFormPage(KOFADisplayFormPage):
     """ Page to view an online payment ticket
     """
@@ -1138,5 +1138,5 @@
 
 
-class AccommodationManageFormPage(SIRPEditFormPage):
+class AccommodationManageFormPage(KOFAEditFormPage):
     """ Page to manage bed tickets.
 
@@ -1195,5 +1195,5 @@
         return self.actions
 
-class BedTicketAddPage(SIRPPage):
+class BedTicketAddPage(KOFAPage):
     """ Page to add an online payment ticket
     """
@@ -1287,7 +1287,7 @@
             'c':room_nr, 'd':bed_nr,
             'e':bed.bed_type})
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         bedticket.bed_coordinates = translate(
-            bc, 'waeup.sirp',target_language=portal_language)
+            bc, 'waeup.kofa',target_language=portal_language)
         key = str(acc_details['booking_session'])
         self.context[key] = bedticket
@@ -1297,5 +1297,5 @@
         return
 
-class BedTicketDisplayFormPage(SIRPDisplayFormPage):
+class BedTicketDisplayFormPage(KOFADisplayFormPage):
     """ Page to display bed tickets
     """
@@ -1325,13 +1325,13 @@
     @property
     def title(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        return translate(_('Bed Allocation Data'), 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        return translate(_('Bed Allocation Data'), 'waeup.kofa',
             target_language=portal_language)
 
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         return translate(_('Bed Allocation: '),
-            'waeup.sirp', target_language=portal_language) \
+            'waeup.kofa', target_language=portal_language) \
             + ' %s' % self.context.bed_coordinates
 
@@ -1405,7 +1405,7 @@
             'c':room_nr, 'd':bed_nr,
             'e':new_bed.bed_type})
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         self.context.bed_coordinates = translate(
-            bc, 'waeup.sirp',target_language=portal_language)
+            bc, 'waeup.kofa',target_language=portal_language)
         self.flash(_('Student relocated: ${a}',
             mapping = {'a':self.context.bed_coordinates}))
@@ -1416,5 +1416,5 @@
         return
 
-class StudentHistoryPage(SIRPPage):
+class StudentHistoryPage(KOFAPage):
     """ Page to display student clearance data
     """
@@ -1431,5 +1431,5 @@
 # Pages for students only
 
-class StudentBaseEditFormPage(SIRPEditFormPage):
+class StudentBaseEditFormPage(KOFAEditFormPage):
     """ View to edit student base data
     """
@@ -1447,5 +1447,5 @@
         return
 
-class StudentChangePasswordPage(SIRPEditFormPage):
+class StudentChangePasswordPage(KOFAEditFormPage):
     """ View to manage student base data
     """
@@ -1473,5 +1473,5 @@
         return
 
-class StudentFilesUploadPage(SIRPPage):
+class StudentFilesUploadPage(KOFAPage):
     """ View to upload files by student
     """
@@ -1490,5 +1490,5 @@
         return
 
-class StartClearancePage(SIRPPage):
+class StartClearancePage(KOFAPage):
     grok.context(IStudent)
     grok.name('start_clearance')
@@ -1593,5 +1593,5 @@
         return
 
-class RequestClearancePage(SIRPPage):
+class RequestClearancePage(KOFAPage):
     grok.context(IStudent)
     grok.name('request_clearance')
@@ -1624,5 +1624,5 @@
         return
 
-class StartCourseRegistrationPage(SIRPPage):
+class StartCourseRegistrationPage(KOFAPage):
     grok.context(IStudentStudyCourse)
     grok.name('start_course_registration')
@@ -1673,5 +1673,5 @@
         return
 
-class AddStudyLevelFormPage(SIRPEditFormPage):
+class AddStudyLevelFormPage(KOFAEditFormPage):
     """ Page for students to add current study levels
     """
@@ -1710,5 +1710,5 @@
         return
 
-class StudyLevelEditFormPage(SIRPEditFormPage):
+class StudyLevelEditFormPage(KOFAEditFormPage):
     """ Page to edit the student study level data by students
     """
@@ -1732,7 +1732,7 @@
     @property
     def label(self):
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
-        level_title = translate(self.context.level_title, 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
+        level_title = translate(self.context.level_title, 'waeup.kofa',
             target_language=lang)
         return _('Add and remove course tickets of study level ${a}',
@@ -1816,5 +1816,5 @@
         return
 
-class ChangePasswordRequestPage(SIRPForm):
+class ChangePasswordRequestPage(KOFAForm):
     """Captcha'd page for students to request a password change.
     """
@@ -1851,11 +1851,11 @@
         student = list(results)[0]
         # Change password
-        sirp_utils = getUtility(ISIRPUtils)
-        pwd = sirp_utils.genPassword()
+        kofa_utils = getUtility(IKOFAUtils)
+        pwd = kofa_utils.genPassword()
         IUserAccount(student).setPassword(pwd)
         # Send email with new redentials
         msg = _('You have successfully changed your password for the')
         login_url = self.url(grok.getSite(), 'login')
-        success = sirp_utils.sendCredentials(
+        success = kofa_utils.sendCredentials(
             IUserAccount(student),pwd,login_url,msg)
         if success:
@@ -1866,6 +1866,6 @@
         return
 
-class SetPasswordPage(SIRPPage):
-    grok.context(ISIRPObject)
+class SetPasswordPage(KOFAPage):
+    grok.context(IKOFAObject)
     grok.name('setpassword')
     grok.require('waeup.Anonymous')
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/accommodationmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/accommodationmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/accommodationmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="display dataTableManage">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basemanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basemanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basemanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <ul class="tabs" data-tabs="tabs">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/basepage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table i18n:domain="waeup.sirp" class="form-table">
+<table i18n:domain="waeup.kofa" class="form-table">
   <tbody>
     <tal:block repeat="widget view/widgets">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/change_password.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/change_password.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/change_password.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <input type="hidden" name="student_id" value=""
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/changepw.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/changepw.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/changepw.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="form-table">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/clearanceeditpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/clearanceeditpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/clearanceeditpage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <ul class="tabs" data-tabs="tabs">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containermanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containermanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containermanagepage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form method="POST" i18n:domain="waeup.sirp">
+<form method="POST" i18n:domain="waeup.kofa">
 <br />
   <input class="btn primary" type="submit" name="search"
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containerpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containerpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/containerpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form method="POST" i18n:domain="waeup.sirp">
+<form method="POST" i18n:domain="waeup.kofa">
 <br />
   <input class="btn primary" type="submit" name="search"
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="post"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="form-table">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/courseticketpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table class="form-table" i18n:domain="waeup.sirp">
+<table class="form-table" i18n:domain="waeup.kofa">
   <tbody>
     <tr>
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/enterpin.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/enterpin.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/enterpin.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form method="POST" i18n:domain="waeup.sirp">
+<form method="POST" i18n:domain="waeup.kofa">
   <table class="form-table">
     <tbody>
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/fileupload.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/fileupload.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/fileupload.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<tr i18n:domain="waeup.sirp">
+<tr i18n:domain="waeup.kofa">
   <td class="fieldname">
     <span tal:replace="viewlet/label">FILENAME</span>:
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/imageupload.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/imageupload.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/imageupload.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<tr i18n:domain="waeup.sirp">
+<tr i18n:domain="waeup.kofa">
   <td class="fieldname">
     <span tal:replace="viewlet/label">FILENAME</span>:
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/paymentsmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/paymentsmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/paymentsmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <table class="display dataTableManage">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/setpassword.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/setpassword.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/setpassword.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<form i18n:domain="waeup.sirp" method="POST">
+<form i18n:domain="waeup.kofa" method="POST">
   <table class="form-table">
     <tbody>
@@ -29,5 +29,5 @@
          tal:attributes="value view/set_button" />
 </form>
-<div i18n:domain="waeup.sirp" >
+<div i18n:domain="waeup.kofa" >
   <h3 i18n:translate="">Instructions:</h3>
   <ul class="list" i18n:translate="">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursemanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursemanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursemanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <ul class="tabs" data-tabs="tabs">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studycoursepage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table class="form-table" i18n:domain="waeup.sirp">
+<table class="form-table" i18n:domain="waeup.kofa">
   <thead>
   </thead>
@@ -50,7 +50,7 @@
 </table>
 
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Study Levels (Course Lists)</h3>
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Study Levels (Course Lists)</h3>
 
-<table i18n:domain="waeup.sirp">
+<table i18n:domain="waeup.kofa">
   <thead>
     <tr>
@@ -70,5 +70,5 @@
 
 <div tal:condition="python: not len(context.keys())"
-    i18n:domain="waeup.sirp" i18n:translate="">
+    i18n:domain="waeup.kofa" i18n:translate="">
   There are no levels registered yet.
 </div>
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveladdpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveladdpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveladdpage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <p i18n:translate="">Text to explain course registration procedure.</p>
@@ -10,5 +10,5 @@
     </span>
   </div>
-</form>  
+</form>
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveleditpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveleditpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studyleveleditpage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <h3 i18n:translate="">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelmanagepage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelmanagepage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelmanagepage.pt	(revision 7811)
@@ -1,4 +1,4 @@
 <form action="." tal:attributes="action request/URL" method="POST"
-      i18n:domain="waeup.sirp" enctype="multipart/form-data">
+      i18n:domain="waeup.kofa" enctype="multipart/form-data">
 
   <ul class="tabs" data-tabs="tabs">
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelpage.pt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelpage.pt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/browser_templates/studylevelpage.pt	(revision 7811)
@@ -1,3 +1,3 @@
-<table class="form-table" i18n:domain="waeup.sirp">
+<table class="form-table" i18n:domain="waeup.kofa">
   <thead>
   </thead>
@@ -26,7 +26,7 @@
 </table>
 
-<h3 i18n:domain="waeup.sirp" i18n:translate="">Course Tickets</h3>
+<h3 i18n:domain="waeup.kofa" i18n:translate="">Course Tickets</h3>
 
-<table class="display dataTable" i18n:domain="waeup.sirp">
+<table class="display dataTable" i18n:domain="waeup.kofa">
   <thead>
     <tr>
@@ -62,5 +62,5 @@
 
 
-<div i18n:domain="waeup.sirp"
+<div i18n:domain="waeup.kofa"
   tal:condition="python: not len(context.keys())" i18n:translate="">
   The're no tickets added yet.
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/catalog.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/catalog.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/catalog.py	(revision 7811)
@@ -24,9 +24,9 @@
 from zope.catalog.interfaces import ICatalog
 from zope.component import queryUtility
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IUniversity, IQueryResultItem, academic_sessions_vocab)
-from waeup.sirp.students.interfaces import (IStudent, ICourseTicket,
+from waeup.kofa.students.interfaces import (IStudent, ICourseTicket,
     IStudentOnlinePayment)
-from waeup.sirp.university.vocabularies import course_levels
+from waeup.kofa.university.vocabularies import course_levels
 
 class StudentIndexes(grok.Indexes):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/container.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/container.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/container.py	(revision 7811)
@@ -20,7 +20,7 @@
 """
 import grok
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentsContainer, IStudent)
-from waeup.sirp.utils.logger import Logger
+from waeup.kofa.utils.logger import Logger
 
 class StudentsContainer(grok.Container, Logger):
@@ -46,5 +46,5 @@
         return
 
-    logger_name = 'waeup.sirp.${sitename}.students'
+    logger_name = 'waeup.kofa.${sitename}.students'
     logger_filename = 'students.log'
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/dynamicroles.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/dynamicroles.py	(revision 7811)
@@ -27,5 +27,5 @@
     AnnotationPrincipalPermissionManager,)
 from zope.securitypolicy.principalrole import AnnotationPrincipalRoleManager
-from waeup.sirp.students.interfaces import IStudent
+from waeup.kofa.students.interfaces import IStudent
 
 # All components in here have the same context: Student instances
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/interfaces.py	(revision 7811)
@@ -21,15 +21,15 @@
 from zope import schema
 from zc.sourcefactory.contextual import BasicContextualSourceFactory
-from waeup.sirp.interfaces import (
-    ISIRPObject, academic_sessions_vocab, validate_email, ISIRPUtils)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.schema import TextLineChoice
-from waeup.sirp.university.vocabularies import CourseSource, StudyModeSource
-from waeup.sirp.students.vocabularies import (
+from waeup.kofa.interfaces import (
+    IKOFAObject, academic_sessions_vocab, validate_email, IKOFAUtils)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.schema import TextLineChoice
+from waeup.kofa.university.vocabularies import CourseSource, StudyModeSource
+from waeup.kofa.students.vocabularies import (
   CertificateSource, StudyLevelSource,
   contextual_reg_num_source, contextual_mat_num_source,
   GenderSource, nats_vocab,
   )
-from waeup.sirp.payments.interfaces import IPaymentsContainer, IOnlinePayment
+from waeup.kofa.payments.interfaces import IPaymentsContainer, IOnlinePayment
 
 # VerdictSource can't be placed into the vocabularies module because it
@@ -78,5 +78,5 @@
         """
 
-class IStudentsContainer(ISIRPObject):
+class IStudentsContainer(IKOFAObject):
     """A students container contains university students.
 
@@ -117,5 +117,5 @@
         """
 
-class IStudentNavigation(ISIRPObject):
+class IStudentNavigation(IKOFAObject):
     """Interface needed for student navigation.
 
@@ -126,5 +126,5 @@
         """
 
-class IStudentBase(ISIRPObject):
+class IStudentBase(IKOFAObject):
     """Representation of student base data.
 
@@ -206,5 +206,5 @@
         )
 
-class IStudentClearance(ISIRPObject):
+class IStudentClearance(IKOFAObject):
     """Representation of student clearance data.
 
@@ -234,5 +234,5 @@
         )
 
-class IStudentPersonal(ISIRPObject):
+class IStudentPersonal(IKOFAObject):
     """Representation of student personal data.
 
@@ -268,5 +268,5 @@
         )
 
-class IStudentStudyCourse(ISIRPObject):
+class IStudentStudyCourse(IKOFAObject):
     """A container for student study levels.
 
@@ -326,5 +326,5 @@
         )
 
-class IStudentStudyLevel(ISIRPObject):
+class IStudentStudyLevel(IKOFAObject):
     """A container for course tickets.
 
@@ -348,5 +348,5 @@
         )
 
-class ICourseTicket(ISIRPObject):
+class ICourseTicket(IKOFAObject):
     """A course ticket.
 
@@ -406,10 +406,10 @@
         )
 
-class IStudentAccommodation(ISIRPObject):
+class IStudentAccommodation(IKOFAObject):
     """A container for student accommodation objects.
 
     """
 
-class IBedTicket(ISIRPObject):
+class IBedTicket(IKOFAObject):
     """A ticket for accommodation booking.
 
@@ -475,5 +475,5 @@
     'p_item'].order
 
-class IStudentChangePassword(ISIRPObject):
+class IStudentChangePassword(IKOFAObject):
     """Interface needed for change pasword page.
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/payments.py	(revision 7811)
@@ -22,8 +22,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentPaymentsContainer, IStudentNavigation, IStudentOnlinePayment)
-from waeup.sirp.payments import PaymentsContainer, OnlinePayment
-from waeup.sirp.utils.helpers import attrs_to_fields
+from waeup.kofa.payments import PaymentsContainer, OnlinePayment
+from waeup.kofa.utils.helpers import attrs_to_fields
 
 class StudentPaymentsContainer(PaymentsContainer):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/student.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/student.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/student.py	(revision 7811)
@@ -26,15 +26,15 @@
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowInfo
 from zope.securitypolicy.interfaces import IPrincipalRoleManager
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IObjectHistory, IUserAccount, IFileStoreNameChooser, IFileStoreHandler,
-    ISIRPUtils, CLEARANCE, registration_states_vocab)
-from waeup.sirp.image import SIRPImageFile
-from waeup.sirp.imagestorage import DefaultFileStoreHandler
-from waeup.sirp.students.interfaces import IStudent, IStudentNavigation
-from waeup.sirp.students.studycourse import StudentStudyCourse
-from waeup.sirp.students.payments import StudentPaymentsContainer
-from waeup.sirp.students.accommodation import StudentAccommodation
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.students.utils import generate_student_id
+    IKOFAUtils, CLEARANCE, registration_states_vocab)
+from waeup.kofa.image import KOFAImageFile
+from waeup.kofa.imagestorage import DefaultFileStoreHandler
+from waeup.kofa.students.interfaces import IStudent, IStudentNavigation
+from waeup.kofa.students.studycourse import StudentStudyCourse
+from waeup.kofa.students.payments import StudentPaymentsContainer
+from waeup.kofa.students.accommodation import StudentAccommodation
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.students.utils import generate_student_id
 
 class Student(grok.Container):
@@ -63,6 +63,6 @@
     def display_fullname(self):
         middlename = getattr(self, 'middlename', None)
-        sirp_utils = getUtility(ISIRPUtils)
-        return sirp_utils.fullname(self.firstname, self.lastname, middlename)
+        kofa_utils = getUtility(IKOFAUtils)
+        return kofa_utils.fullname(self.firstname, self.lastname, middlename)
 
     @property
@@ -204,5 +204,5 @@
 
     This chooser is registered as an adapter providing
-    :class:`waeup.sirp.interfaces.IFileStoreNameChooser`.
+    :class:`waeup.kofa.interfaces.IFileStoreNameChooser`.
 
     File store name choosers like this one are only convenience
@@ -211,5 +211,5 @@
     manually setting up filenames for students.
 
-    .. seealso:: :mod:`waeup.sirp.imagestorage`
+    .. seealso:: :mod:`waeup.kofa.imagestorage`
 
     """
@@ -284,4 +284,4 @@
             StudentFileStoreHandler, self).createFile(
             store, root,  filename, file_id, file)
-        return file, path, SIRPImageFile(
+        return file, path, KOFAImageFile(
             file_obj.filename, file_obj.data)
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/studycourse.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/studycourse.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/studycourse.py	(revision 7811)
@@ -23,8 +23,8 @@
 from zope.component.interfaces import IFactory
 from zope.interface import implementedBy
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentStudyCourse, IStudentNavigation, IStudentStudyLevel)
-from waeup.sirp.students.studylevel import CourseTicket
-from waeup.sirp.utils.helpers import attrs_to_fields
+from waeup.kofa.students.studylevel import CourseTicket
+from waeup.kofa.utils.helpers import attrs_to_fields
 
 class StudentStudyCourse(grok.Container):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/studylevel.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/studylevel.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/studylevel.py	(revision 7811)
@@ -22,8 +22,8 @@
 import grok
 from zope.component.interfaces import IFactory
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentStudyLevel, IStudentNavigation, ICourseTicket)
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.students.vocabularies import StudyLevelSource
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.students.vocabularies import StudyLevelSource
 
 class StudentStudyLevel(grok.Container):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_authentication.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_authentication.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_authentication.py	(revision 7811)
@@ -26,10 +26,10 @@
 from zope.securitypolicy.role import Role
 from zope.securitypolicy.interfaces import IRole, Allow
-from waeup.sirp.authentication import get_principal_role_manager
-from waeup.sirp.interfaces import IAuthPluginUtility, IUserAccount
-from waeup.sirp.students.authentication import (
+from waeup.kofa.authentication import get_principal_role_manager
+from waeup.kofa.interfaces import IAuthPluginUtility, IUserAccount
+from waeup.kofa.students.authentication import (
     StudentsAuthenticatorSetup, StudentAccount)
-from waeup.sirp.students.tests.test_browser import StudentsFullSetup
-from waeup.sirp.testing import FunctionalLayer
+from waeup.kofa.students.tests.test_browser import StudentsFullSetup
+from waeup.kofa.testing import FunctionalLayer
 
 class StudentsAuthenticatorSetupTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_batching.py	(revision 7811)
@@ -28,14 +28,14 @@
 from zope.interface.verify import verifyClass, verifyObject
 
-from waeup.sirp.app import University
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
-from waeup.sirp.students.batching import (
+from waeup.kofa.app import University
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
+from waeup.kofa.students.batching import (
     StudentProcessor, StudentStudyCourseProcessor,
     StudentStudyLevelProcessor, CourseTicketProcessor,
     StudentOnlinePaymentProcessor)
-from waeup.sirp.students.student import Student
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.interfaces import IBatchProcessor
+from waeup.kofa.students.student import Student
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.interfaces import IBatchProcessor
 
 STUDENT_SAMPLE_DATA = open(
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_browser.py	(revision 7811)
@@ -33,14 +33,14 @@
 from zope.testbrowser.testing import Browser
 from hurry.workflow.interfaces import IWorkflowInfo, IWorkflowState
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.app import University
-from waeup.sirp.configuration import SessionConfiguration
-from waeup.sirp.students.student import Student
-from waeup.sirp.students.studylevel import StudentStudyLevel
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
-from waeup.sirp.interfaces import IUserAccount
-from waeup.sirp.authentication import LocalRoleSetEvent
-from waeup.sirp.hostels.hostel import Hostel, Bed, NOT_OCCUPIED
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.configuration import SessionConfiguration
+from waeup.kofa.students.student import Student
+from waeup.kofa.students.studylevel import StudentStudyLevel
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
+from waeup.kofa.interfaces import IUserAccount
+from waeup.kofa.authentication import LocalRoleSetEvent
+from waeup.kofa.hostels.hostel import Hostel, Bed, NOT_OCCUPIED
 
 PH_LEN = 2059  # Length of placeholder file
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_catalog.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_catalog.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_catalog.py	(revision 7811)
@@ -23,10 +23,10 @@
 from zope.component import queryUtility, createObject
 from zope.component.hooks import setSite
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.students.student import Student
-from waeup.sirp.students.studylevel import StudentStudyLevel, CourseTicket
-from waeup.sirp.university.faculty import Faculty
-from waeup.sirp.university.department import Department
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.students.student import Student
+from waeup.kofa.students.studylevel import StudentStudyLevel, CourseTicket
+from waeup.kofa.university.faculty import Faculty
+from waeup.kofa.university.department import Department
 
 class CatalogTestSetup(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_container.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_container.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_container.py	(revision 7811)
@@ -23,13 +23,13 @@
 from zope.interface.verify import verifyClass, verifyObject
 from zope.component.hooks import setSite, clearSite
-from waeup.sirp.app import University
-from waeup.sirp.university.department import Department
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.app import University
+from waeup.kofa.university.department import Department
+from waeup.kofa.students.interfaces import (
     IStudentsContainer,
     )
-from waeup.sirp.students.container import (
+from waeup.kofa.students.container import (
     StudentsContainer, 
     )
-from waeup.sirp.testing import (
+from waeup.kofa.testing import (
     FunctionalLayer, FunctionalTestCase, remove_logger)
 
@@ -39,5 +39,5 @@
 
     def setUp(self):
-        remove_logger('waeup.sirp.app.students')
+        remove_logger('waeup.kofa.app.students')
         super(StudentsContainerTestCase, self).setUp()
         # Setup a sample site for each test
@@ -86,5 +86,5 @@
         logger = self.app['students'].logger
         assert logger is not None
-        assert logger.name == 'waeup.sirp.app.students'
+        assert logger.name == 'waeup.kofa.app.students'
         handlers = logger.handlers
         assert len(handlers) == 1
@@ -100,5 +100,5 @@
         logger = self.app['students'].logger
         assert logger is not None
-        assert logger.name == 'waeup.sirp.app.students'
+        assert logger.name == 'waeup.kofa.app.students'
         handlers = logger.handlers
         assert len(handlers) == 1
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_dynamicroles.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_dynamicroles.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_dynamicroles.py	(revision 7811)
@@ -24,7 +24,7 @@
 from zope.securitypolicy.tests.test_annotationprincipalrolemanager import (
     Test as APRMTest, Manageable)
-from waeup.sirp.testing import FunctionalLayer
-from waeup.sirp.students.tests.test_browser import StudentsFullSetup
-from waeup.sirp.students import Student, StudentPrincipalRoleManager
+from waeup.kofa.testing import FunctionalLayer
+from waeup.kofa.students.tests.test_browser import StudentsFullSetup
+from waeup.kofa.students import Student, StudentPrincipalRoleManager
 
 class StudentPrincipalRoleManagerTests(APRMTest):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_payment.py	(revision 7811)
@@ -20,9 +20,9 @@
 """
 
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.students.payments import (
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.students.payments import (
     StudentOnlinePayment, StudentOnlinePaymentFactory)
-from waeup.sirp.payments.interfaces import IOnlinePayment
-from waeup.sirp.students.interfaces import IStudentNavigation
+from waeup.kofa.payments.interfaces import IOnlinePayment
+from waeup.kofa.students.interfaces import IStudentNavigation
 
 class StudentOnlinePaymentFactoryTest(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_student.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_student.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_student.py	(revision 7811)
@@ -20,15 +20,15 @@
 from zope.component.interfaces import IFactory
 from zope.interface import verify
-from waeup.sirp.students.student import Student, StudentFactory
-from waeup.sirp.students.studycourse import StudentStudyCourse
-from waeup.sirp.students.studylevel import StudentStudyLevel, CourseTicket
-from waeup.sirp.students.payments import StudentPaymentsContainer
-from waeup.sirp.students.accommodation import StudentAccommodation, BedTicket
-from waeup.sirp.applicants.interfaces import IApplicantBaseData
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.student import Student, StudentFactory
+from waeup.kofa.students.studycourse import StudentStudyCourse
+from waeup.kofa.students.studylevel import StudentStudyLevel, CourseTicket
+from waeup.kofa.students.payments import StudentPaymentsContainer
+from waeup.kofa.students.accommodation import StudentAccommodation, BedTicket
+from waeup.kofa.applicants.interfaces import IApplicantBaseData
+from waeup.kofa.students.interfaces import (
     IStudent, IStudentStudyCourse, IStudentPaymentsContainer, IStudentAccommodation,
     IStudentStudyLevel, ICourseTicket, IBedTicket)
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.university.department import Department
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.university.department import Department
 
 class StudentTest(FunctionalTestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_utils.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_utils.py	(revision 7811)
@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 import unittest
-from waeup.sirp.students.utils import formatted_text
+from waeup.kofa.students.utils import formatted_text
 
 class FormatterTests(unittest.TestCase):
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_vocabularies.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_vocabularies.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/tests/test_vocabularies.py	(revision 7811)
@@ -17,6 +17,6 @@
 ##
 import unittest
-from waeup.sirp.students.vocabularies import StudyLevelSource
-from waeup.sirp.university.certificate import Certificate
+from waeup.kofa.students.vocabularies import StudyLevelSource
+from waeup.kofa.university.certificate import Certificate
 
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/utils.py	(revision 7811)
@@ -35,7 +35,7 @@
 from zope.component import getUtility
 from zope.formlib.form import setUpEditWidgets
-from waeup.sirp.interfaces import IExtFileStore, ISIRPUtils
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.students.interfaces import IStudentsUtils
+from waeup.kofa.interfaces import IExtFileStore, IKOFAUtils
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.students.interfaces import IStudentsUtils
 
 SLIP_STYLE = [
@@ -108,15 +108,15 @@
         studentview.context, attr='passport.jpg')
     if img is None:
-        from waeup.sirp.browser import DEFAULT_PASSPORT_IMAGE_PATH
+        from waeup.kofa.browser import DEFAULT_PASSPORT_IMAGE_PATH
         img = open(DEFAULT_PASSPORT_IMAGE_PATH, 'rb')
     doc_img = Image(img.name, width=4*cm, height=4*cm, kind='bound')
     data_left.append([doc_img])
     #data.append([Spacer(1, 12)])
-    portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+    portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
     for widget in studentview.widgets:
         if widget.name == 'form.adm_code':
             continue
         f_label = formatted_label(size=12) % translate(
-            widget.label.strip(), 'waeup.sirp',
+            widget.label.strip(), 'waeup.kofa',
             target_language=portal_language)
         f_label = Paragraph(f_label, style["Normal"])
@@ -164,8 +164,8 @@
       story = []
       frame_footer = Frame(1*cm,0,width-(2*cm),1*cm)
-      portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+      portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
       right_text = translate(_('<font size=10>${a} Page ${b} of ${c}</font>',
           mapping = {'a':text, 'b':pdf.getPageNumber(), 'c':number_of_pages}),
-          'waeup.sirp', target_language=portal_language)
+          'waeup.kofa', target_language=portal_language)
       story.append(Paragraph(right_text, style["Right"]))
       frame_footer.addFromList(story,pdf)
@@ -256,5 +256,5 @@
         pdf.setAuthor('%s (%s)' % (view.request.principal.title,
             view.request.principal.id))
-        pdf.setCreator('WAeUP SIRP')
+        pdf.setCreator('WAeUP KOFA')
         width, height = A4
         footer_text = view.label
@@ -275,9 +275,9 @@
         frame_body = Frame(1*cm,1*cm,width-(2*cm),height-(3.5*cm))
         story.append(Paragraph(view.label, style["Heading2"]))
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         if student is not None:
             #story.append(Spacer(1, 12))
             bd_translation = translate(_('Base Data'),
-                'waeup.sirp', target_language=portal_language)
+                'waeup.kofa', target_language=portal_language)
             story.append(Paragraph(bd_translation, style["Heading3"]))
             studenttable = render_student_data(studentview)
@@ -288,8 +288,8 @@
         set_up_widgets(view)
         data = []
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
         for widget in view.widgets:
             f_label = '<font size=12>%s</font>:' % translate(
-                widget.label.strip(), 'waeup.sirp',
+                widget.label.strip(), 'waeup.kofa',
                 target_language=portal_language)
             f_label = Paragraph(f_label, style["Normal"])
@@ -302,6 +302,6 @@
         # Import browser components locally
         # to avoid circular import
-        from waeup.sirp.students.viewlets import FileManager
-        from waeup.sirp.browser import DEFAULT_IMAGE_PATH
+        from waeup.kofa.students.viewlets import FileManager
+        from waeup.kofa.browser import DEFAULT_IMAGE_PATH
         data = []
         # Collect viewlets
@@ -309,5 +309,5 @@
         fm.update()
         if fm.viewlets:
-            sc_translation = translate(_('Scanned Documents'), 'waeup.sirp',
+            sc_translation = translate(_('Scanned Documents'), 'waeup.kofa',
                 target_language=portal_language)
             story.append(Paragraph(sc_translation, style["Heading3"]))
@@ -315,5 +315,5 @@
             for viewlet in fm.viewlets:
                 f_label = formatted_label(size=12) % translate(
-                viewlet.label, 'waeup.sirp',
+                viewlet.label, 'waeup.kofa',
                 target_language=portal_language)
                 f_label = Paragraph(f_label, style["Normal"])
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/vocabularies.py	(revision 7811)
@@ -25,14 +25,14 @@
 from zc.sourcefactory.basic import BasicSourceFactory
 from zc.sourcefactory.contextual import BasicContextualSourceFactory
-from waeup.sirp.interfaces import SimpleSIRPVocabulary
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.students.lgas import LGAS
-from waeup.sirp.students.nats import NATS
-from waeup.sirp.university.vocabularies import course_levels
+from waeup.kofa.interfaces import SimpleKOFAVocabulary
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.students.lgas import LGAS
+from waeup.kofa.students.nats import NATS
+from waeup.kofa.university.vocabularies import course_levels
 
-lgas_vocab = SimpleSIRPVocabulary(
+lgas_vocab = SimpleKOFAVocabulary(
     *sorted([(x[1],x[0]) for x in LGAS]))
 
-nats_vocab = SimpleSIRPVocabulary(
+nats_vocab = SimpleKOFAVocabulary(
     *sorted([(x[1],x[0]) for x in NATS]))
 
Index: main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/workflow.py	(revision 7811)
@@ -5,11 +5,11 @@
 from hurry.workflow.workflow import Transition, WorkflowState, NullCondition
 from hurry.workflow.interfaces import IWorkflowState, IWorkflowTransitionEvent
-from waeup.sirp.interfaces import (
-    IObjectHistory, ISIRPWorkflowInfo, ISIRPUtils,
+from waeup.kofa.interfaces import (
+    IObjectHistory, IKOFAWorkflowInfo, IKOFAUtils,
     CREATED, ADMITTED, CLEARANCE, REQUESTED, CLEARED, PAID, RETURNING,
     REGISTERED, VALIDATED)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.workflow import SIRPWorkflow, SIRPWorkflowInfo
-from waeup.sirp.students.interfaces import IStudent, IStudentsUtils
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.workflow import KOFAWorkflow, KOFAWorkflowInfo
+from waeup.kofa.students.interfaces import IStudent, IStudentsUtils
 
 
@@ -156,5 +156,5 @@
 UNLOCK_CLEARANCE_TRANS = ('reset3', 'reset4', 'start_clearance')
 
-registration_workflow = SIRPWorkflow(REGISTRATION_TRANSITIONS)
+registration_workflow = KOFAWorkflow(REGISTRATION_TRANSITIONS)
 
 class RegistrationWorkflowState(WorkflowState, grok.Adapter):
@@ -167,9 +167,9 @@
     state_id = 'wf.registration.id'
 
-class RegistrationWorkflowInfo(SIRPWorkflowInfo, grok.Adapter):
+class RegistrationWorkflowInfo(KOFAWorkflowInfo, grok.Adapter):
     """Adapter to adapt Student objects to workflow info objects.
     """
     grok.context(IStudent)
-    grok.provides(ISIRPWorkflowInfo)
+    grok.provides(IKOFAWorkflowInfo)
 
     def __init__(self, context):

Index: main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/students/viewlets.py	(revision 7811)
@@ -21,15 +21,15 @@
 from zope.interface import Interface
 from zope.i18n import translate
-from waeup.sirp.interfaces import (
-    ISIRPObject, IExtFileStore, IFileStoreNameChooser, ISIRPUtils)
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.utils.helpers import string_from_bytes, file_size
-from waeup.sirp.browser import DEFAULT_IMAGE_PATH
-from waeup.sirp.browser.viewlets import (
+from waeup.kofa.interfaces import (
+    IKOFAObject, IExtFileStore, IFileStoreNameChooser, IKOFAUtils)
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.utils.helpers import string_from_bytes, file_size
+from waeup.kofa.browser import DEFAULT_IMAGE_PATH
+from waeup.kofa.browser.viewlets import (
     PrimaryNavTab, ManageActionButton, AddActionButton)
-from waeup.sirp.browser.layout import default_primary_nav_template
-from waeup.sirp.students.workflow import (ADMITTED, PAID,
+from waeup.kofa.browser.layout import default_primary_nav_template
+from waeup.kofa.students.workflow import (ADMITTED, PAID,
     CLEARANCE, REQUESTED, RETURNING, CLEARED, REGISTERED, VALIDATED)
-from waeup.sirp.students.browser import (
+from waeup.kofa.students.browser import (
     StudentClearanceManageFormPage,
     write_log_message, StudentBaseManageFormPage,
@@ -40,5 +40,5 @@
     CourseTicketDisplayFormPage, OnlinePaymentDisplayFormPage,
     AccommodationManageFormPage, BedTicketDisplayFormPage,)
-from waeup.sirp.students.interfaces import (
+from waeup.kofa.students.interfaces import (
     IStudentsContainer, IStudent, IStudentClearance,
     IStudentStudyCourse, IStudentAccommodation, IStudentStudyLevel,
@@ -46,7 +46,7 @@
     )
 
-from waeup.sirp.interfaces import MessageFactory as _
-
-grok.context(ISIRPObject) # Make ISIRPObject the default context
+from waeup.kofa.interfaces import MessageFactory as _
+
+grok.context(IKOFAObject) # Make IKOFAObject the default context
 grok.templatedir('browser_templates')
 
@@ -63,5 +63,5 @@
     grok.baseclass()
     grok.viewletmanager(StudentManageSidebar)
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.view(Interface)
     grok.order(5)
@@ -73,7 +73,7 @@
     def render(self):
         url = self.view.url(self.context.getStudent(), self.link)
-        portal_language = getUtility(ISIRPUtils).PORTAL_LANGUAGE
-        lang = self.request.cookies.get('sirp.language', portal_language)
-        text = translate(self.text, 'waeup.sirp',
+        portal_language = getUtility(IKOFAUtils).PORTAL_LANGUAGE
+        lang = self.request.cookies.get('kofa.language', portal_language)
+        text = translate(self.text, 'waeup.kofa',
             target_language=lang)
         return u'<li><a href="%s">%s</a></li>' % (
@@ -465,5 +465,5 @@
     """
 
-    grok.context(ISIRPObject)
+    grok.context(IKOFAObject)
     grok.order(4)
     grok.require('waeup.viewStudentsTab')